Function esp32_simple::thread::failure
source · pub fn failure() -> !Expand description
Handles program failure by restarting the device.
This function waits for a second and then restarts the device if the program encounters an error.